==> haskell-structured-0.1.0.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.0.1
visibility:           public
id:                   structured-0.1.0.1-LZAdCrRPSKyJuCUDClOTio
key:                  structured-0.1.0.1-LZAdCrRPSKyJuCUDClOTio
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  570d3f1de57d3768a8aeb5c0fbe48d89
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-8.10.4/site-local/structured-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/structured-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/structured-0.1.0.1
hs-libraries:         HSstructured-0.1.0.1-LZAdCrRPSKyJuCUDClOTio
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn array-0.5.4.0 base-4.14.1.0
    base16-bytestring-1.0.1.0-JclBqFMO1eX94FYTHG5WbF binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    scientific-0.3.6.2-3drxgAmnSntDv0pyrC0U61
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1
    time-compat-1.9.5-4jbTSB5GFw17R6UOiP5nco transformers-0.5.6.2
    unordered-containers-0.2.13.0-3zq6q89i05VC2WIEWnQHAq
    uuid-types-1.0.4-8rpbn2k9f5BBV4kDieqEuf
    vector-0.12.2.0-6U3O0KyAitXJQBfpQxiTi1

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.0.1
visibility:           public
id:                   structured-0.1.0.1-Ou02wCUks118Oc1UJnQZU
key:                  structured-0.1.0.1-Ou02wCUks118Oc1UJnQZU
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  662ced87a71808ae9ada10298db0cb96
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-8.10.4/site-local/structured-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/structured-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/structured-0.1.0.1
hs-libraries:         HSstructured-0.1.0.1-Ou02wCUks118Oc1UJnQZU
depends:
    aeson-1.5.6.0-8KXcI8eaJDb23YvdvZt7uT array-0.5.4.0 base-4.14.1.0
    base16-bytestring-1.0.1.0-AgE6rY2lVzm8SIlM9gmSzI binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    hashable-1.3.1.0-3O2Bzk2rCtQQYcJkJ3vPV
    scientific-0.3.6.2-21jjdCL1aCqC58ACrk6SAS
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1
    time-compat-1.9.5-6fvQNXlVgJbLIIFWkd4udw transformers-0.5.6.2
    unordered-containers-0.2.13.0-Db75j8fMRzh4s5oxHejudG
    uuid-types-1.0.4-DUBSBy5BLruKLFE0LkQGbg
    vector-0.12.3.0-9sHYkvizLwxkl2zr3W4dm

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
